==> gst-plugins-bad1.0_1.2.4.orig.tar.xz: gst-plugins-bad-1.2.4/ext/srtp/gstsrtpenc.h <==
/*
 * GStreamer - GStreamer SRTP encoder
 *
 * Copyright 2009 Collabora Ltd.
 *  @author: Gabriel Millaire <gabriel.millaire@collabora.co.uk>
 *  @author: Olivier Crete <olivier.crete@collabora.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * Alternatively, the contents of this file may be used under the
 * GNU Lesser General Public License Version 2.1 (the "LGPL"), in
 * which case the following provisions apply instead of the ones
 * mentioned above:
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GST_SRTPENC_H__
#define __GST_SRTPENC_H__

#include <gst/gst.h>
#include <srtp/srtp.h>

G_BEGIN_DECLS

#define GST_TYPE_SRTP_ENC \
  (gst_srtp_enc_get_type())
#define GST_SRTP_ENC(obj)                                              \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_SRTP_ENC,GstSrtpEnc))
#define GST_SRTP_ENC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_SRTP_ENC,GstSrtpEncClass))
#define GST_IS_SRTP_ENC(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_SRTP_ENC))
#define GST_IS_SRTP_ENC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_SRTP_ENC))

typedef struct _GstSrtpEnc      GstSrtpEnc;
typedef struct _GstSrtpEncClass GstSrtpEncClass;

struct _GstSrtpEnc
{
  GstElement element;

  gboolean random_key;

  GstBuffer *key;
  guint rtp_cipher;
  guint rtp_auth;
  guint rtcp_cipher;
  guint rtcp_auth;

  srtp_t session;
  gboolean first_session;
  gboolean key_changed;

  gboolean hard_limit_reached;
  gboolean soft_limit_reached;

  GHashTable *ssrcs_set;

  GType key_type;
};

struct _GstSrtpEncClass
{
  GstElementClass parent_class;
};

GType gst_srtp_enc_get_type (void);

gboolean gst_srtp_enc_plugin_init (GstPlugin * plugin);

G_END_DECLS

#endif /* __GST_SRTPENC_H__ */

==> gst-plugins-bad1.0_1.8.3.orig.tar.xz: gst-plugins-bad-1.8.3/ext/srtp/gstsrtpenc.h <==
/*
 * GStreamer - GStreamer SRTP encoder
 *
 * Copyright 2009 Collabora Ltd.
 *  @author: Gabriel Millaire <gabriel.millaire@collabora.co.uk>
 *  @author: Olivier Crete <olivier.crete@collabora.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * Alternatively, the contents of this file may be used under the
 * GNU Lesser General Public License Version 2.1 (the "LGPL"), in
 * which case the following provisions apply instead of the ones
 * mentioned above:
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GST_SRTPENC_H__
#define __GST_SRTPENC_H__

#include <gst/gst.h>
#include <srtp/srtp.h>

G_BEGIN_DECLS

#define GST_TYPE_SRTP_ENC \
  (gst_srtp_enc_get_type())
#define GST_SRTP_ENC(obj)                                              \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_SRTP_ENC,GstSrtpEnc))
#define GST_SRTP_ENC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_SRTP_ENC,GstSrtpEncClass))
#define GST_IS_SRTP_ENC(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_SRTP_ENC))
#define GST_IS_SRTP_ENC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_SRTP_ENC))

typedef struct _GstSrtpEnc      GstSrtpEnc;
typedef struct _GstSrtpEncClass GstSrtpEncClass;

struct _GstSrtpEnc
{
  GstElement element;

  gboolean random_key;

  GstBuffer *key;
  guint rtp_cipher;
  guint rtp_auth;
  guint rtcp_cipher;
  guint rtcp_auth;

  srtp_t session;
  gboolean first_session;
  gboolean key_changed;

  guint replay_window_size;
  gboolean allow_repeat_tx;
};

struct _GstSrtpEncClass
{
  GstElementClass parent_class;

  /* action signals */
  guint32 (*get_rollover_counter) (GstSrtpEnc *encoder, guint32 ssrc);
};

GType gst_srtp_enc_get_type (void);

gboolean gst_srtp_enc_plugin_init (GstPlugin * plugin);

G_END_DECLS

#endif /* __GST_SRTPENC_H__ */
